/*-
# MS WINDOWS-BASED DINOSAUR CUBE
#
#  wdino.h
#
###
#
#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wdino.c */

#define IDM_GET		100
#define IDM_WRITE	101
#define IDM_EXIT	102
#define IDM_HIDE	103
#define IDM_UNDO	200
#define IDM_REDO	201
#define IDM_CLEAR	202
#define IDM_RANDOMIZE	203
#define IDM_PRACTICE	204
#define IDM_SOLVE	205
#define IDM_ORIENTIZE	206
#define IDM_DIM 	207
#define IDM_TR		300
#define IDM_BR		301
#define IDM_BL		302
#define IDM_TL		303
#define IDM_CW		305
#define IDM_CCW		307
#define IDM_TOP		308
#define IDM_RIGHT	309
#define IDM_BOTTOM	310
#define IDM_LEFT	311
#define IDM_SHIFT_TR	320
#define IDM_SHIFT_BR	321
#define IDM_SHIFT_BL	322
#define IDM_SHIFT_TL	323
#define IDM_SHIFT_CW	325
#define IDM_SHIFT_CCW	327
#define IDM_SHIFT_TOP	328
#define IDM_SHIFT_RIGHT	329
#define IDM_SHIFT_BOTTOM	330
#define IDM_SHIFT_LEFT	331
#define IDM_CONTROL_TR	340
#define IDM_CONTROL_BR	341
#define IDM_CONTROL_BL	342
#define IDM_CONTROL_TL	343
#define IDM_CONTROL_CW	345
#define IDM_CONTROL_CCW	347
#define IDM_CONTROL_TOP	348
#define IDM_CONTROL_RIGHT	349
#define IDM_CONTROL_BOTTOM	350
#define IDM_CONTROL_LEFT	351
#define IDM_SHIFTCONTROL_TR	360
#define IDM_SHIFTCONTROL_BR	361
#define IDM_SHIFTCONTROL_BL	362
#define IDM_SHIFTCONTROL_TL	363
#define IDM_SHIFTCONTROL_CW	365
#define IDM_SHIFTCONTROL_CCW	367
#define IDM_SHIFTCONTROL_TOP	368
#define IDM_SHIFTCONTROL_RIGHT	369
#define IDM_SHIFTCONTROL_BOTTOM	370
#define IDM_SHIFTCONTROL_LEFT	371
#define IDM_ALT_TR	380
#define IDM_ALT_BR	381
#define IDM_ALT_BL	382
#define IDM_ALT_TL	383
#define IDM_ALT_CW	385
#define IDM_ALT_CCW	387
#define IDM_ALT_TOP	388
#define IDM_ALT_RIGHT	389
#define IDM_ALT_BOTTOM	390
#define IDM_ALT_LEFT	391
#define IDM_CONTROLALT_TR	400
#define IDM_CONTROLALT_BR	401
#define IDM_CONTROLALT_BL	402
#define IDM_CONTROLALT_TL	403
#define IDM_CONTROLALT_CW	405
#define IDM_CONTROLALT_CCW	407
#define IDM_CONTROLALT_TOP	408
#define IDM_CONTROLALT_RIGHT	409
#define IDM_CONTROLALT_BOTTOM	410
#define IDM_CONTROLALT_LEFT	411
#define IDM_PERIOD2	450
#define IDM_PERIOD3	451
#define IDM_BOTH	452
#define IDM_ABOUT	500
#define IDM_DESCRIPTION	501
#define IDM_FEATURES	502
#define IDM_REFERENCES	503
